SAstNodeFactory class

Factory for deserializing AST nodes

Constructors

SAstNodeFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic>? json) SAstNode?
Deserialize a node from JSON
listFromJson<T extends SAstNode>(List? jsonList) List<T>
Deserialize a list of nodes from JSON
register(String nodeType, SAstNode factory(Map<String, dynamic>)) → void
Register a factory for a node type