SClassDeclaration class
- Inheritance
-
- Object
- SAstNode
- SAnnotatedNode
- SDeclaration
- SCompilationUnitMember
- SNamedCompilationUnitMember
- SClassDeclaration
- Mixed-in types
Constructors
-
SClassDeclaration({required int offset, required int length, SSimpleIdentifier? name, List<
SAnnotation> metadata = const [], bool isAbstract = false, bool isSealed = false, bool isBase = false, bool isInterface = false, bool isFinal = false, bool isMixin = false, STypeParameterList? typeParameters, SExtendsClause? extendsClause, SImplementsClause? implementsClause, SWithClause? withClause, List<SClassMember> members = const []}) -
SClassDeclaration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- end → int
-
Get the end offset
no setterinherited
- extendsClause → SExtendsClause?
-
Extends clause
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- implementsClause → SImplementsClause?
-
Implements clause
final
- isAbstract → bool
-
Class modifiers
final
- isBase → bool
-
final
- isFinal → bool
-
final
- isInterface → bool
-
final
- isMixin → bool
-
final
- isSealed → bool
-
final
- length → int
-
Length of the source text
final
-
members
→ List<
SClassMember> -
Class members (fields, methods, constructors)
final
-
metadata
→ List<
SAnnotation> -
Documentation comment, if any.
final
- name → SSimpleIdentifier?
-
final
- nodeType → String
-
Unique node type identifier for serialization
no setteroverride
- offset → int
-
Source offset of the node
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeParameters → STypeParameterList?
-
Type parameters
final
- withClause → SWithClause?
-
With clause
final
Methods
-
accept<
T> (SAstVisitor< T> visitor) → T? -
Accept a visitor and return the result.
override
-
equals(
Object other, [List< String> ? log]) → bool -
Compares this node with
other. Iflogis provided, differences are appended in a human-readable format with JSON-style paths.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON-serializable map
override
-
toJsonString(
{bool pretty = false}) → String -
Serialize to JSON string
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
SAstVisitor visitor) → void -
Visit all child nodes of this node.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited