SFunctionDeclaration class
- Inheritance
-
- Object
- SAstNode
- SAnnotatedNode
- SDeclaration
- SCompilationUnitMember
- SNamedCompilationUnitMember
- SFunctionDeclaration
- Mixed-in types
Constructors
-
SFunctionDeclaration({required int offset, required int length, SSimpleIdentifier? name, List<
SAnnotation> metadata = const [], STypeAnnotation? returnType, bool isGetter = false, bool isSetter = false, bool isExternal = false, STypeParameterList? typeParameters, SFunctionExpression? functionExpression}) -
SFunctionDeclaration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- end → int
-
Get the end offset
no setterinherited
- functionExpression → SFunctionExpression?
-
The function expression (parameters and body)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExternal → bool
-
Whether external
final
- isGetter → bool
-
Whether this is a getter
final
- isSetter → bool
-
Whether this is a setter
final
- length → int
-
Length of the source text
final
-
metadata
→ List<
SAnnotation> -
Documentation comment, if any.
final
- name → SSimpleIdentifier?
-
final
- nodeType → String
-
Unique node type identifier for serialization
no setteroverride
- offset → int
-
Source offset of the node
final
- returnType → STypeAnnotation?
-
Return type annotation
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeParameters → STypeParameterList?
-
Type parameters (generics)
final
Methods
-
accept<
T> (SAstVisitor< T> visitor) → T? -
Accept a visitor and return the result.
override
-
equals(
Object other, [List< String> ? log]) → bool -
Compares this node with
other. Iflogis provided, differences are appended in a human-readable format with JSON-style paths.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON-serializable map
override
-
toJsonString(
{bool pretty = false}) → String -
Serialize to JSON string
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
SAstVisitor visitor) → void -
Visit all child nodes of this node.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited