SStringInterpolation class
- Inheritance
-
- Object
- SAstNode
- SCollectionElement
- SExpression
- SLiteral
- SStringLiteral
- SSingleStringLiteral
- SStringInterpolation
Constructors
-
SStringInterpolation({required int offset, required int length, List<
SInterpolationElement> elements = const [], bool isMultiline = false, bool isRaw = false}) -
SStringInterpolation.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
elements
→ List<
SInterpolationElement> -
final
- end → int
-
Get the end offset
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMultiline → bool
-
Whether this is a multiline string.
final
- isRaw → bool
-
Whether this is a raw string.
final
- length → int
-
Length of the source text
final
- nodeType → String
-
Unique node type identifier for serialization
no setteroverride
- offset → int
-
Source offset of the node
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String?
-
The value of this string literal, or null if it contains interpolations
that cannot be statically evaluated.
no setteroverride
Methods
-
accept<
T> (SAstVisitor< T> visitor) → T? -
Accept a visitor and return the result.
override
-
equals(
Object other, [List< String> ? log]) → bool -
Compares this node with
other. Iflogis provided, differences are appended in a human-readable format with JSON-style paths.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON-serializable map
override
-
toJsonString(
{bool pretty = false}) → String -
Serialize to JSON string
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
SAstVisitor visitor) → void -
Visit all child nodes of this node.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited