SAstNode class abstract
Base class for all serializable AST nodes
- Implementers
- SAnnotatedNode
- SAnnotation
- SArgumentList
- SCaseClause
- SCatchClause
- SCollectionElement
- SCombinator
- SComment
- SCompilationUnit
- SConstructorInitializer
- SConstructorName
- SDartPattern
- SExtendsClause
- SForLoopParts
- SFormalParameter
- SFormalParameterList
- SFunctionBody
- SFunctionBodyOwner
- SGuardedPattern
- SImplementsClause
- SInterpolationElement
- SLabel
- SMapPatternEntry
- SNamedDeclaration
- SOnClause
- SPatternField
- SPatternFieldName
- SRecordTypeField
- SRepresentationDeclaration
- SRestPatternElement
- SStatement
- SSwitchExpressionCase
- SSwitchMember
- STypeAnnotation
- STypeArgumentList
- STypeParameterList
- SWhenClause
- SWithClause
Constructors
- SAstNode()
Properties
- end → int
-
Get the end offset
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- length → int
-
Length of the source text
no setter
- nodeType → String
-
Unique node type identifier for serialization
no setter
- offset → int
-
Source offset of the node
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept<
T> (SAstVisitor< T> visitor) → T? - Accept a visitor and return the result.
-
equals(
Object other, [List< String> ? log]) → bool -
Compares this node with
other. Iflogis provided, differences are appended in a human-readable format with JSON-style paths. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON-serializable map
-
toJsonString(
{bool pretty = false}) → String - Serialize to JSON string
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
SAstVisitor visitor) → void - Visit all child nodes of this node.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override